@@ -1,3 +1,8 @@
+pub use bit_reader::BitReader;
+pub use types::float32::F32Compressor;
+pub use types::float32::F32Decompressor;
+pub use types::float64::F64Compressor;
+pub use types::float64::F64Decompressor;
 pub use types::signed32::I32Compressor;
 pub use types::signed32::I32Decompressor;
 pub use types::signed64::I64Compressor;
@@ -7,13 +12,15 @@ pub use types::unsigned32::U32Decompressor;
 pub use types::unsigned64::U64Compressor;
 pub use types::unsigned64::U64Decompressor;
 
-pub use crate::bit_reader::BitReader;
+pub use constants::MAX_ENTRIES;
 
-pub mod huffman;
+mod constants;
+mod huffman;
+mod prefix;
+mod utils;
+pub mod bit_reader;
 pub mod bits;
+pub mod compressor;
+pub mod decompressor;
+pub mod errors;
 pub mod types;
-pub mod prefix;
-pub mod utils;
-mod bit_reader;
-mod compressor;
-mod decompressor;
