@@ -1,19 +1,27 @@
-use crate::types::{NumberLike, DataType};
+use std::cmp::Ordering;
 use std::convert::TryInto;
+
 use crate::compressor::Compressor;
 use crate::decompressor::Decompressor;
+use crate::types::{DataType, NumberLike};
+
+impl NumberLike for i64 {
+  fn num_eq(&self, other: &Self) -> bool {
+    self.eq(other)
+  }
+
+  fn num_cmp(&self, other: &Self) -> Ordering {
+    self.cmp(other)
+  }
+}
 
 pub struct I64DataType {}
 
-impl NumberLike for i64 {}
-
 impl DataType<i64> for I64DataType {
   const HEADER_BYTE: u8 = 1;
   const BIT_SIZE: usize = 64;
-  const ZERO: i64 = 0;
 
-  #[inline(always)]
-  fn u64_diff(upper: i64, lower: i64) -> u64 {
+  fn offset_diff(upper: i64, lower: i64) -> u64 {
     if lower >= 0 {
       (upper - lower) as u64
     } else if lower == upper {
@@ -28,8 +36,7 @@ impl DataType<i64> for I64DataType {
     }
   }
 
-  #[inline(always)]
-  fn add_u64(lower: i64, off: u64) -> i64 {
+  fn add_offset(lower: i64, off: u64) -> i64 {
     if lower >= 0 {
       (lower as u64 + off) as i64
     } else if off == 0 {
