@@ -1,24 +1,31 @@
-use crate::types::{NumberLike, DataType};
+use std::cmp::Ordering;
 use std::convert::TryInto;
+
 use crate::compressor::Compressor;
 use crate::decompressor::Decompressor;
+use crate::types::{DataType, NumberLike};
+
+impl NumberLike for u32 {
+  fn num_eq(&self, other: &Self) -> bool {
+    self.eq(other)
+  }
+
+  fn num_cmp(&self, other: &Self) -> Ordering {
+    self.cmp(other)
+  }
+}
 
 pub struct U32DataType {}
 
-impl NumberLike for u32 {}
-
 impl DataType<u32> for U32DataType {
   const HEADER_BYTE: u8 = 4;
   const BIT_SIZE: usize = 32;
-  const ZERO: u32 = 0;
 
-  #[inline(always)]
-  fn u64_diff(upper: u32, lower: u32) -> u64 {
+  fn offset_diff(upper: u32, lower: u32) -> u64 {
     (upper - lower) as u64
   }
 
-  #[inline(always)]
-  fn add_u64(lower: u32, off: u64) -> u32 {
+  fn add_offset(lower: u32, off: u64) -> u32 {
     lower + off as u32
   }
 
